const Main = imports.ui.main;
const PanelMenu = imports.ui.panelMenu;
const PopupMenu = imports.ui.popupMenu;
const Tweener = imports.ui.tweener;
const Lang = imports.lang;
const Gio = imports.gi.Gio;
const GLib = imports.gi.GLib;
const Gtk = imports.gi.Gtk;
const Shell = imports.gi.Shell;
const St = imports.gi.St;


let _file, _userMenu, _dateMenu, _option, _invisible, _setLeft, _setRight, _setCenter;


function init( meta ) {

  _file = meta.path + "/custom_clock.dat";
  _userMenu = Main.panel.statusArea.userMenu;
  _dateMenu = Main.panel.statusArea.dateMenu;

}


function enable() {

  _invisible = new PopupMenu.PopupSwitchMenuItem( _( "Invisible Calendar" ) );
  _invisible.connect( 'activate', Lang.bind( _userMenu, invisible ) );

  read();

  _setCenter = new PopupMenu.PopupMenuItem( _( "Show Center" ) );
  _setLeft = new PopupMenu.PopupMenuItem( _( "Show Left Side" ) );
  _setRight = new PopupMenu.PopupMenuItem( _( "Show Right Side" ) );
  _setCenter.connect( 'activate', Lang.bind( _dateMenu, setCenter ) );
  _setLeft.connect( 'activate', Lang.bind( _dateMenu, setLeft ) );
  _setRight.connect( 'activate', Lang.bind( _dateMenu, setRight ) );

  _option = new PopupMenu.PopupSubMenuMenuItem(_("Options") );
  _option.menu.addMenuItem( _setCenter );
  _option.menu.addMenuItem( _setLeft );
  _option.menu.addMenuItem( _setRight );
  
  let items = _userMenu.menu._getMenuItems();
  for( let i = 0; i < items.length; i++ ){
    if( items[i] == _userMenu._systemSettings || i >= items.length -1 ){
      _userMenu.menu.addMenuItem( _invisible, i );
      _userMenu.menu.addMenuItem( _option, i + 1 );
      _userMenu.menu.addMenuItem( new PopupMenu.PopupSeparatorMenuItem(), i + 2 );
      break;
    }
  }
}


function disable() {
  Main.panel._rightBox.remove_actor( _dateMenu.container );
  Main.panel._centerBox.add_actor( _dateMenu.container );
  
  _invisible.destroy();
  _option.destroy();

  _option = null;
  _invisible = null;
  _setLeft = null;
  _setRight = null;
  _setCenter = null;
}


function invisible( item ) {
  Main.panel._centerBox.remove_actor( _dateMenu.container );
  Main.panel._leftBox.remove_actor( _dateMenu.container );
  if( item.state ){
    Main.panel._rightBox.remove_actor( _dateMenu.container );
    Main.panel._leftBox.remove_actor( _dateMenu.container );
    Main.panel._centerBox.remove_actor( _dateMenu.container );
    
    write( 'invisible' );
  }else{
    Main.panel._centerBox.insert_child_at_index( _dateMenu.container, 0 );
    invisibleButton();
    write( 'center' );
  }
}


function invisibleButton(){
  _invisible.setToggleState( false );
}


function setCenter() { 
  Main.panel._rightBox.remove_actor( _dateMenu.container );
  Main.panel._leftBox.remove_actor( _dateMenu.container );
  Main.panel._centerBox.insert_child_at_index( _dateMenu.container, 0 );
  write( 'center' );
}


function setDefault(){
  setCenter();
  invisibleButton();
}


function setLeft() {
  Main.panel._rightBox.remove_actor( _dateMenu.container );
  Main.panel._centerBox.remove_actor( _dateMenu.container );
  if( Main.panel._leftBox.get_children().length > 0 ){
    Main.panel._leftBox.insert_child_at_index( _dateMenu.container, Main.panel._leftBox.get_children().length -1 );
  }else{
    Main.panel._leftBox.insert_child_at_index( _dateMenu.container, 0 );
  }
  invisibleButton();
  write( 'left' );
}


function setRight() { 
  Main.panel._centerBox.remove_actor( _dateMenu.container );
  Main.panel._leftBox.remove_actor( _dateMenu.container );
  Main.panel._rightBox.insert_child_at_index( _dateMenu.container, 0 );
  invisibleButton();
  write( 'right' );
}


function read(){
	if( GLib.file_test( _file, GLib.FileTest.EXISTS ) ){
		let content = Shell.get_file_contents_utf8_sync( _file );
		let dat = content.toString();
    if( dat == 'left' ){
      setLeft();
    }else if( dat == 'right' ){
      setRight();
    }else if( dat == 'invisible' ){
      _invisible.setToggleState( true );
      invisible( _invisible );
    }else{
      setCenter();
    }
	}
	else { global.logError("Todo list : Error while reading file : " + varFile); }
}


function write( text ){
	if( GLib.file_test( _file, GLib.FileTest.EXISTS ) ){
		let content = Shell.get_file_contents_utf8_sync( _file );
		content = text
		
		let f = Gio.file_new_for_path( _file );
		let out = f.replace( null, false, Gio.FileCreateFlags.NONE, null );
		Shell.write_string_to_stream( out, content );
		out.close( null );
	}else{
		global.logError("Todo list : Error while reading file : " + file);
	}
}

